==> certmanager-model-v1alpha3-5.7.3-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CertificateStatusBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CertificateStatusBuilder extends io.fabric8.certmanager.api.model.v1alpha3.CertificateStatusFluentImpl<io.fabric8.certmanager.api.model.v1alpha3.CertificateStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.certmanager.api.model.v1alpha3.CertificateStatus,io.fabric8.certmanager.api.model.v1alpha3.CertificateStatusBuilder>{
  public CertificateStatusBuilder() {
    this(false);
  }
  public CertificateStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new CertificateStatus(), validationEnabled);
  }
  public CertificateStatusBuilder(io.fabric8.certmanager.api.model.v1alpha3.CertificateStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateStatusBuilder(io.fabric8.certmanager.api.model.v1alpha3.CertificateStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CertificateStatus(), validationEnabled);
  }
  public CertificateStatusBuilder(io.fabric8.certmanager.api.model.v1alpha3.CertificateStatusFluent<?> fluent,io.fabric8.certmanager.api.model.v1alpha3.CertificateStatus instance) {
    this(fluent, instance, false);
  }
  public CertificateStatusBuilder(io.fabric8.certmanager.api.model.v1alpha3.CertificateStatusFluent<?> fluent,io.fabric8.certmanager.api.model.v1alpha3.CertificateStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withLastFailureTime(instance.getLastFailureTime()); 
    fluent.withNextPrivateKeySecretName(instance.getNextPrivateKeySecretName()); 
    fluent.withNotAfter(instance.getNotAfter()); 
    fluent.withNotBefore(instance.getNotBefore()); 
    fluent.withRenewalTime(instance.getRenewalTime()); 
    fluent.withRevision(instance.getRevision()); 
    this.validationEnabled = validationEnabled; 
  }
  public CertificateStatusBuilder(io.fabric8.certmanager.api.model.v1alpha3.CertificateStatus instance) {
    this(instance,false);
  }
  public CertificateStatusBuilder(io.fabric8.certmanager.api.model.v1alpha3.CertificateStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withLastFailureTime(instance.getLastFailureTime()); 
    this.withNextPrivateKeySecretName(instance.getNextPrivateKeySecretName()); 
    this.withNotAfter(instance.getNotAfter()); 
    this.withNotBefore(instance.getNotBefore()); 
    this.withRenewalTime(instance.getRenewalTime()); 
    this.withRevision(instance.getRevision()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.certmanager.api.model.v1alpha3.CertificateStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.certmanager.api.model.v1alpha3.CertificateStatus build() {
    CertificateStatus buildable = new CertificateStatus(fluent.getConditions(),fluent.getLastFailureTime(),fluent.getNextPrivateKeySecretName(),fluent.getNotAfter(),fluent.getNotBefore(),fluent.getRenewalTime(),fluent.getRevision());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CertificateStatusBuilder that = (CertificateStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> certmanager-model-v1alpha3-6.6.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CertificateStatusBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CertificateStatusBuilder extends CertificateStatusFluentImpl<CertificateStatusBuilder> implements VisitableBuilder<CertificateStatus,CertificateStatusBuilder>{
  public CertificateStatusBuilder() {
    this(false);
  }
  public CertificateStatusBuilder(Boolean validationEnabled) {
    this(new CertificateStatus(), validationEnabled);
  }
  public CertificateStatusBuilder(CertificateStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateStatusBuilder(CertificateStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CertificateStatus(), validationEnabled);
  }
  public CertificateStatusBuilder(CertificateStatusFluent<?> fluent,CertificateStatus instance) {
    this(fluent, instance, false);
  }
  public CertificateStatusBuilder(CertificateStatusFluent<?> fluent,CertificateStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withLastFailureTime(instance.getLastFailureTime()); 
    fluent.withNextPrivateKeySecretName(instance.getNextPrivateKeySecretName()); 
    fluent.withNotAfter(instance.getNotAfter()); 
    fluent.withNotBefore(instance.getNotBefore()); 
    fluent.withRenewalTime(instance.getRenewalTime()); 
    fluent.withRevision(instance.getRevision()); 
    this.validationEnabled = validationEnabled; 
  }
  public CertificateStatusBuilder(CertificateStatus instance) {
    this(instance,false);
  }
  public CertificateStatusBuilder(CertificateStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withLastFailureTime(instance.getLastFailureTime()); 
    this.withNextPrivateKeySecretName(instance.getNextPrivateKeySecretName()); 
    this.withNotAfter(instance.getNotAfter()); 
    this.withNotBefore(instance.getNotBefore()); 
    this.withRenewalTime(instance.getRenewalTime()); 
    this.withRevision(instance.getRevision()); 
    this.validationEnabled = validationEnabled; 
  }
  CertificateStatusFluent<?> fluent;
  Boolean validationEnabled;
  public CertificateStatus build() {
    CertificateStatus buildable = new CertificateStatus(fluent.getConditions(),fluent.getLastFailureTime(),fluent.getNextPrivateKeySecretName(),fluent.getNotAfter(),fluent.getNotBefore(),fluent.getRenewalTime(),fluent.getRevision());
    return buildable;
  }
  
}
